@@ -1,7 +1,7 @@
 from borsh_construct import *
 from solana.publickey import PublicKey
 from solana.transaction import TransactionInstruction, AccountMeta
-from state import ClassEnum
+from .state import ClassEnum
 
 
 InstructionEnum = Enum(
